==> causeway-bom-2.1.0-source-release.zip: causeway-bom-2.1.0/core/webapp/src/main/java/org/apache/causeway/core/webapp/routing/RedirectFilter.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package org.apache.causeway.core.webapp.routing;

import java.io.IOException;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.causeway.commons.internal.resources._Resources;

public class RedirectFilter implements Filter {

    private String redirectTo;

    protected void doGet(final HttpServletRequest request, final HttpServletResponse response) throws ServletException, IOException {

    }

    @Override
    public void init(final FilterConfig filterConfig) throws ServletException {
        redirectTo = filterConfig.getInitParameter("redirectTo");
    }

    @Override
    public void doFilter(final ServletRequest request, final ServletResponse response, final FilterChain chain) throws IOException, ServletException {
        final HttpServletRequest httpServletRequest = (HttpServletRequest) request;
        final HttpServletResponse httpServletResponse = (HttpServletResponse) response;

        httpServletResponse.sendRedirect(_Resources.combinePath(httpServletRequest.getContextPath(), redirectTo));
    }

    @Override
    public void destroy() {

    }

}

==> causeway-bom-3.5.0-source-release.zip: causeway-bom-3.5.0/core/webapp/src/main/java/org/apache/causeway/core/webapp/routing/RedirectFilter.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package org.apache.causeway.core.webapp.routing;

import java.io.IOException;

import jakarta.servlet.Filter;
import jakarta.servlet.FilterChain;
import jakarta.servlet.FilterConfig;
import jakarta.servlet.ServletException;
import jakarta.servlet.ServletRequest;
import jakarta.servlet.ServletResponse;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;

import org.apache.causeway.commons.internal.resources._Resources;

public class RedirectFilter implements Filter {

    private String redirectTo;

    protected void doGet(final HttpServletRequest request, final HttpServletResponse response) throws ServletException, IOException {

    }

    @Override
    public void init(final FilterConfig filterConfig) throws ServletException {
        redirectTo = filterConfig.getInitParameter("redirectTo");
    }

    @Override
    public void doFilter(final ServletRequest request, final ServletResponse response, final FilterChain chain) throws IOException, ServletException {
        final HttpServletRequest httpServletRequest = (HttpServletRequest) request;
        final HttpServletResponse httpServletResponse = (HttpServletResponse) response;

        httpServletResponse.sendRedirect(_Resources.combinePath(httpServletRequest.getContextPath(), redirectTo));
    }

    @Override
    public void destroy() {

    }

}
